@@ -4,10 +4,7 @@ use 5.006001;
 use strict;
 use warnings;
 
-our $VERSION = "1.00";
-
-use Tie::Hash;
-use base 'Tie::ExtraHash'; # defined in Tie/Hash.pm
+our $VERSION = "1.01";
 
 sub new {
     my ($class, $defsub, %params) = @_;
@@ -47,6 +44,14 @@ sub STORE {
   }
 }
 
+# copied from Tie::ExtraHash in perl-5.10.1/lib/Tie/Hash.pm
+sub FIRSTKEY { my $a = scalar keys %{$_[0][0]}; each %{$_[0][0]} }
+sub NEXTKEY  { each %{$_[0][0]} }
+sub EXISTS   { exists $_[0][0]->{$_[1]} }
+sub DELETE   { delete $_[0][0]->{$_[1]} }
+sub CLEAR    { %{$_[0][0]} = () }
+sub SCALAR   { scalar %{$_[0][0]} }
+
 1;
 
 
